@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright 2013 EMBL-EBI
+ * Copyright 2013-2016 EMBL-EBI
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -292,7 +292,7 @@ public class CRAMIterator implements SAMRecordIterator {
 
     @Override
     public SAMRecordIterator assertSorted(final SortOrder sortOrder) {
-        throw new RuntimeException("Not implemented.");
+        return SamReader.AssertingIterator.of(this).assertSorted(sortOrder);
     }
 
     public SamReader getFileSource() {
