@@ -28,6 +28,7 @@ import htsjdk.samtools.util.SortingCollection;
 
 import java.io.File;
 import java.io.StringWriter;
+import java.util.function.Supplier;
 
 /**
  * Base class for implementing SAM writer with any underlying format.
@@ -105,14 +106,14 @@ public abstract class SAMFileWriterImpl implements SAMFileWriter
      * before spilling to disk.  Must be called before setHeader().
      * @param maxRecordsInRam
      */
-    void setMaxRecordsInRam(final int maxRecordsInRam) {
+    protected void setMaxRecordsInRam(final int maxRecordsInRam) {
         if (this.header != null) {
             throw new IllegalStateException("setMaxRecordsInRam must be called before setHeader()");
         }
         this.maxRecordsInRam = maxRecordsInRam;
     }
 
-    int getMaxRecordsInRam() {
+    protected int getMaxRecordsInRam() {
         return maxRecordsInRam;
     }
 
@@ -121,13 +122,13 @@ public abstract class SAMFileWriterImpl implements SAMFileWriter
      * for spilling to disk.  Must be called before setHeader().
      * @param tmpDir path to the temporary directory
      */
-    void setTempDirectory(final File tmpDir) {
+    protected void setTempDirectory(final File tmpDir) {
         if (tmpDir!=null) {
             this.tmpDir = tmpDir;
         }
     }
 
-    File getTempDirectory() {
+    protected File getTempDirectory() {
         return tmpDir;
     }
 
@@ -144,11 +145,8 @@ public abstract class SAMFileWriterImpl implements SAMFileWriter
              sortOrder = SAMFileHeader.SortOrder.unsorted;
         }
         header.setSortOrder(sortOrder);
-        final StringWriter headerTextBuffer = new StringWriter();
-        new SAMTextHeaderCodec().encode(headerTextBuffer, header);
-        final String headerText = headerTextBuffer.toString();
 
-        writeHeader(headerText);
+        writeHeader(header);
 
         if (presorted) {
             if (sortOrder.equals(SAMFileHeader.SortOrder.unsorted)) {
@@ -243,9 +241,27 @@ public abstract class SAMFileWriterImpl implements SAMFileWriter
     /**
      * Write the header to disk.  Header object is available via getHeader().
      * @param textHeader for convenience if the implementation needs it.
+     * @deprecated since 06/2018. {@link #writeHeader(SAMFileHeader)} is preferred for avoid String construction if not need it.
      */
+    @Deprecated
     abstract protected void writeHeader(String textHeader);
 
+    /**
+     * Write the header to disk. Header object is available via getHeader().
+     *
+     * <p>IMPORTANT: this method will be abstract once {@link #writeHeader(String)} is removed.
+     *
+     * <p>Note: default implementation uses {@link SAMTextHeaderCodec#encode} and calls
+     * {@link #writeHeader(String)}.
+     *
+     * @param header object to write.
+     */
+    protected void writeHeader(final SAMFileHeader header) {
+        final StringWriter headerTextBuffer = new StringWriter();
+        new SAMTextHeaderCodec().encode(headerTextBuffer, header);
+        writeHeader(headerTextBuffer.toString());
+    }
+
     /**
      * Do any required flushing here.
      */
