@@ -65,12 +65,14 @@ public class SAMRecordSetBuilder implements Iterable<SAMRecord> {
 
     private int readLength = 36;
 
+    private boolean useBamFile = true;
+
     private SAMProgramRecord programRecord = null;
     private SAMReadGroupRecord readGroup = null;
     private boolean useNmFlag = false;
 
     private boolean unmappedHasBasesAndQualities = true;
-    
+
     public static final int DEFAULT_CHROMOSOME_LENGTH = 200000000;
 
     public static final ScoringStrategy DEFAULT_DUPLICATE_SCORING_STRATEGY = ScoringStrategy.TOTAL_MAPPED_REFERENCE_LENGTH;
@@ -134,6 +136,16 @@ public class SAMRecordSetBuilder implements Iterable<SAMRecord> {
         }
     }
 
+    /**
+     * Determine whether the class will use a bam (default) or a sam file to hold the
+     * records when providing a reader to them.
+     *
+     * @param useBamFile if true will use a BAM file, otherwise it will use a SAM file to hold the records.
+     */
+    public void setUseBamFile(final boolean useBamFile) {
+        this.useBamFile = useBamFile;
+    }
+
     public void setUnmappedHasBasesAndQualities(final boolean value) {
         this.unmappedHasBasesAndQualities = value;
     }
@@ -175,15 +187,20 @@ public class SAMRecordSetBuilder implements Iterable<SAMRecord> {
         }
     }
 
-    /** Returns the accumulated list of sam records. */
-    public Collection<SAMRecord> getRecords() { return this.records; }
+    /**
+     * Returns the accumulated list of sam records.
+     */
+    public Collection<SAMRecord> getRecords() {
+        return this.records;
+    }
 
     public void setHeader(final SAMFileHeader header) {
         this.header = header.clone();
     }
 
-
-    /** The record should already have the DS and MC tags computed */
+    /**
+     * The record should already have the DS and MC tags computed
+     */
     public void addRecord(final SAMRecord record) {
         if (record.getReadPairedFlag() && !record.getMateUnmappedFlag() &&
                 null == record.getAttribute(SAMTagUtil.getSingleton().MC)) {
@@ -192,7 +209,9 @@ public class SAMRecordSetBuilder implements Iterable<SAMRecord> {
         this.records.add(record);
     }
 
-    /** Returns a CloseableIterator over the collection of SAMRecords. */
+    /**
+     * Returns a CloseableIterator over the collection of SAMRecords.
+     */
     @Override
     public CloseableIterator<SAMRecord> iterator() {
         return new CloseableIterator<SAMRecord>() {
@@ -202,13 +221,19 @@ public class SAMRecordSetBuilder implements Iterable<SAMRecord> {
             public void close() { /** Do nothing. */}
 
             @Override
-            public boolean hasNext() { return this.iterator.hasNext(); }
+            public boolean hasNext() {
+                return this.iterator.hasNext();
+            }
 
             @Override
-            public SAMRecord next() { return this.iterator.next(); }
+            public SAMRecord next() {
+                return this.iterator.next();
+            }
 
             @Override
-            public void remove() { this.iterator.remove(); }
+            public void remove() {
+                this.iterator.remove();
+            }
         };
     }
 
@@ -242,7 +267,7 @@ public class SAMRecordSetBuilder implements Iterable<SAMRecord> {
         }
         rec.setAttribute(SAMTag.RG.name(), READ_GROUP_ID);
 
-        if(useNmFlag){
+        if (useNmFlag) {
             rec.setAttribute(SAMTag.NM.name(), SequenceUtil.calculateSamNmTagFromCigar(rec));
         }
 
@@ -255,7 +280,7 @@ public class SAMRecordSetBuilder implements Iterable<SAMRecord> {
         }
 
         if (!recordUnmapped || this.unmappedHasBasesAndQualities) {
-        fillInBasesAndQualities(rec, qualityString, defaultQuality);
+            fillInBasesAndQualities(rec, qualityString, defaultQuality);
         }
 
         return rec;
@@ -306,7 +331,6 @@ public class SAMRecordSetBuilder implements Iterable<SAMRecord> {
         return rec;
     }
 
-
     /**
      * Fills in the bases and qualities for the given record. Quality data is randomly generated if the defaultQuality
      * is set to -1. Otherwise all qualities will be set to defaultQuality. If a quality string is provided that string
@@ -322,11 +346,20 @@ public class SAMRecordSetBuilder implements Iterable<SAMRecord> {
         }
     }
 
+    /** If the record contains a cigar with non-zero read length, return that length, otherwise, return readLength
+     */
+    private int getReadLengthFromCigar(final SAMRecord rec) {
+        return ( rec.getCigar() != null &&
+                 rec.getCigar().getReadLength() != 0 ) ? rec.getCigar().getReadLength() : readLength;
+    }
+
     /**
      * Randomly fills in the bases for the given record.
+     * <p>
+     * If there's a cigar with read-length >0, will use that length for reads. Otherwise will use length = 36
      */
     private void fillInBases(final SAMRecord rec) {
-        final int length = this.readLength;
+        final int length = getReadLengthFromCigar(rec);
         final byte[] bases = new byte[length];
 
         for (int i = 0; i < length; ++i) {
@@ -343,7 +376,6 @@ public class SAMRecordSetBuilder implements Iterable<SAMRecord> {
         addFrag(name, -1, -1, false, true, null, null, -1, false);
     }
 
-
     /**
      * Adds a skeletal pair of records to the set using the provided
      * contig starts.  The pair is assumed to be a well
@@ -359,7 +391,7 @@ public class SAMRecordSetBuilder implements Iterable<SAMRecord> {
         end1.setAlignmentStart(start1);
         end1.setReadNegativeStrandFlag(false);
         end1.setCigarString(readLength + "M");
-        if(useNmFlag) end1.setAttribute(ReservedTagConstants.NM, 0);
+        if (useNmFlag) end1.setAttribute(ReservedTagConstants.NM, 0);
         end1.setMappingQuality(255);
         end1.setReadPairedFlag(true);
         end1.setProperPairFlag(true);
@@ -379,7 +411,7 @@ public class SAMRecordSetBuilder implements Iterable<SAMRecord> {
         end2.setAlignmentStart(start2);
         end2.setReadNegativeStrandFlag(true);
         end2.setCigarString(readLength + "M");
-        if(useNmFlag) end2.setAttribute(ReservedTagConstants.NM,0);
+        if (useNmFlag) end2.setAttribute(ReservedTagConstants.NM, 0);
         end2.setMappingQuality(255);
         end2.setReadPairedFlag(true);
         end2.setProperPairFlag(true);
@@ -519,10 +551,10 @@ public class SAMRecordSetBuilder implements Iterable<SAMRecord> {
     /**
      * Fills in bases and qualities with a set default quality. If the defaultQuality is set to -1 quality scores will
      * be randomly generated.
-     * Relies on the alignment start and end having been set to get read length.
+     * If there's a cigar with read-length >0, will use that length for reads. Otherwise will use length = 36
      */
     private void fillInBasesAndQualities(final SAMRecord rec, final int defaultQuality) {
-        final int length = this.readLength;
+        final int length = getReadLengthFromCigar(rec);
         final byte[] quals = new byte[length];
 
         if (-1 != defaultQuality) {
@@ -546,29 +578,30 @@ public class SAMRecordSetBuilder implements Iterable<SAMRecord> {
         final File tempFile;
 
         try {
-            tempFile = File.createTempFile("temp", ".sam");
+            tempFile = File.createTempFile("temp", this.useBamFile ? ".bam" : ".sam");
+            tempFile.deleteOnExit();
         } catch (final IOException e) {
             throw new RuntimeIOException("problems creating tempfile", e);
         }
 
         this.header.setAttribute("VN", "1.0");
-        final SAMFileWriter w = new SAMFileWriterFactory().makeBAMWriter(this.header, true, tempFile);
-        for (final SAMRecord r : this.getRecords()) {
-            w.addAlignment(r);
+        try(final SAMFileWriter w = this.useBamFile ?
+                new SAMFileWriterFactory().makeBAMWriter(this.header, true, tempFile) :
+                new SAMFileWriterFactory().makeSAMWriter(this.header, true, tempFile)) {
+            for (final SAMRecord r : this.getRecords()) {
+                w.addAlignment(r);
+            }
         }
 
-        w.close();
-
-        final SamReader reader = SamReaderFactory.makeDefault().validationStringency(ValidationStringency.SILENT).open(tempFile);
-        tempFile.deleteOnExit();
-
-        return reader;
+        return SamReaderFactory.makeDefault().validationStringency(ValidationStringency.SILENT).open(tempFile);
     }
 
     public SAMFileHeader getHeader() {
         return header;
     }
 
-    public void setReadLength(final int readLength) { this.readLength = readLength; }
+    public void setReadLength(final int readLength) {
+        this.readLength = readLength;
+    }
 
 }
