@@ -208,10 +208,8 @@ public class SamFileValidator {
     }
 
     public void validateBamFileTermination(final File inputFile) {
-        BufferedInputStream inputStream = null;
         try {
-            inputStream = IOUtil.toBufferedStream(new FileInputStream(inputFile));
-            if (!BlockCompressedInputStream.isValidFile(inputStream)) {
+            if (!IOUtil.isBlockCompressed(inputFile.toPath())) {
                 return;
             }
             final BlockCompressedInputStream.FileTermination terminationState =
@@ -227,10 +225,6 @@ public class SamFileValidator {
             }
         } catch (IOException e) {
             throw new SAMException("IOException", e);
-        } finally {
-            if (inputStream != null) {
-                CloserUtil.close(inputStream);
-            }
         }
     }
 
@@ -244,8 +238,7 @@ public class SamFileValidator {
                 try {
                     if (indexValidationStringency == IndexValidationStringency.LESS_EXHAUSTIVE) {
                         BamIndexValidator.lessExhaustivelyTestIndex(samReader);
-                    }
-                    else {
+                    } else {
                         BamIndexValidator.exhaustivelyTestIndex(samReader);
                     }
                 } catch (Exception e) {
@@ -344,7 +337,7 @@ public class SamFileValidator {
 
                 }
 
-                if ((qualityNotStoredErrorCount++ < MAX_QUALITY_NOT_STORED_ERRORS) && record.getBaseQualityString().equals("*")){
+                if ((qualityNotStoredErrorCount++ < MAX_QUALITY_NOT_STORED_ERRORS) && record.getBaseQualityString().equals("*")) {
                     addError(new SAMValidationError(Type.QUALITY_NOT_STORED,
                             "QUAL field is set to * (unspecified quality scores), this is allowed by the SAM" +
                                     " specification but many tools expect reads to include qualities ",
@@ -390,15 +383,33 @@ public class SamFileValidator {
     }
 
     /**
-     * Report error if a tag value is a Long.
+     * Report error if a tag value is a Long, or if there's a duplicate dag,
+     * or if there's a CG tag is obvered (CG tags are converted to cigars in
+     * the bam code, and should not appear in other formats)
      */
     private void validateTags(final SAMRecord record, final long recordNumber) {
-        for (final SAMRecord.SAMTagAndValue tagAndValue : record.getAttributes()) {
+        final List<SAMRecord.SAMTagAndValue> attributes = record.getAttributes();
+
+        final Set<String> tags = new HashSet<>(attributes.size());
+
+        for (final SAMRecord.SAMTagAndValue tagAndValue : attributes) {
             if (tagAndValue.value instanceof Long) {
                 addError(new SAMValidationError(Type.TAG_VALUE_TOO_LARGE,
                         "Numeric value too large for tag " + tagAndValue.tag,
                         record.getReadName(), recordNumber));
             }
+
+            if (!tags.add(tagAndValue.tag)) {
+                addError(new SAMValidationError(Type.DUPLICATE_SAM_TAG,
+                        "Duplicate SAM tag (" + tagAndValue.tag + ") found.", record.getReadName(), recordNumber));
+            }
+        }
+
+        if (tags.contains(SAMTag.CG.name())){
+            addError(new SAMValidationError(Type.CG_TAG_FOUND_IN_ATTRIBUTES,
+                    "The CG Tag should only be used in BAM format to hold a large cigar. " +
+                            "It was found containing the value: " +
+                            record.getAttribute(SAMTagUtil.getSingleton().CG), record.getReadName(), recordNumber));
         }
     }
 
@@ -457,7 +468,6 @@ public class SamFileValidator {
         return valid;
     }
 
-
     private boolean validateSortOrder(final SAMRecord record, final long recordNumber) {
         final SAMRecord prev = orderChecker.getPreviousRecord();
         boolean isValidSortOrder = orderChecker.isSorted(record);
@@ -593,8 +603,7 @@ public class SamFileValidator {
                 addError(new SAMValidationError(Type.MISSING_PLATFORM_VALUE,
                         "A platform (PL) attribute was not found for read group ",
                         readGroupID));
-            }
-            else {
+            } else {
                 // NB: cannot be null, so not catching a NPE
                 try {
                     SAMReadGroupRecord.PlatformValue.valueOf(platformValue.toUpperCase());
@@ -631,7 +640,7 @@ public class SamFileValidator {
 
         switch (error.getType().severity) {
             case WARNING:
-                if ( this.ignoreWarnings ) {
+                if (this.ignoreWarnings) {
                     return;
                 }
                 this.numWarnings++;
