@@ -43,15 +43,11 @@ import ngs.Read;
 import ngs.Fragment;
 import ngs.ErrorMsg;
 
-import java.io.IOException;
 import java.util.EnumSet;
 import java.util.Set;
-import java.util.HashSet;
 import java.util.Map;
 import java.util.HashMap;
 import java.util.List;
-import java.lang.reflect.InvocationTargetException;
-import java.lang.reflect.Method;
 
 /**
  * Extends SAMRecord so that any of the fields will be loaded only when needed.
@@ -157,10 +153,10 @@ public class SRALazyRecord extends SAMRecord {
                 return self.getProperPairFlag();
             }
         },
-        NOT_PRIMARY_ALIGNMENT(true) {
+        SECONDARY_ALIGNMENT(true) {
             @Override
             public boolean getFlag(SRALazyRecord self) {
-                return self.getNotPrimaryAlignmentFlag();
+                return self.isSecondaryAlignment();
             }
         },
         MATE_NEGATIVE_STRAND(false) {
@@ -533,19 +529,19 @@ public class SRALazyRecord extends SAMRecord {
     }
 
     @Override
-    public boolean getNotPrimaryAlignmentFlag() {
-        if (!initializedFlags.contains(LazyFlag.NOT_PRIMARY_ALIGNMENT)) {
-            setNotPrimaryAlignmentFlag(getNotPrimaryAlignmentFlagImpl());
+    public boolean isSecondaryAlignment() {
+        if (!initializedFlags.contains(LazyFlag.SECONDARY_ALIGNMENT)) {
+            setSecondaryAlignment(getSecondaryAlignmentFlagImpl());
         }
-        return super.getNotPrimaryAlignmentFlag();
+        return super.isSecondaryAlignment();
     }
 
     @Override
-    public void setNotPrimaryAlignmentFlag(final boolean flag) {
-        if (!initializedFlags.contains(LazyFlag.NOT_PRIMARY_ALIGNMENT)) {
-            initializedFlags.add(LazyFlag.NOT_PRIMARY_ALIGNMENT);
+    public void setSecondaryAlignment(final boolean flag) {
+        if (!initializedFlags.contains(LazyFlag.SECONDARY_ALIGNMENT)) {
+            initializedFlags.add(LazyFlag.SECONDARY_ALIGNMENT);
         }
-        super.setNotPrimaryAlignmentFlag(flag);
+        super.setSecondaryAlignment(flag);
     }
 
     @Override
@@ -675,6 +671,7 @@ public class SRALazyRecord extends SAMRecord {
         return super.getBinaryAttributes();
     }
 
+    @Override
     public boolean isUnsignedArrayAttribute(final String tag) {
         Short binaryTag = SAMTagUtil.getSingleton().makeBinaryTag(tag);
         LazyAttribute attr = lazyAttributeTags.get(binaryTag);
@@ -950,7 +947,7 @@ public class SRALazyRecord extends SAMRecord {
         return isAligned && getReadPairedFlag() && !getMateUnmappedFlag();
     }
 
-    private boolean getNotPrimaryAlignmentFlagImpl() {
+    private boolean getSecondaryAlignmentFlagImpl() {
         try {
             if (isAligned) {
                 return getCurrentAlignment().getAlignmentCategory() == Alignment.secondaryAlignment;
