@@ -33,7 +33,10 @@ import org.testng.annotations.Test;
 
 import java.io.*;
 import java.util.Arrays;
+import java.util.Collection;
+import java.util.Collections;
 import java.util.List;
+import java.util.Optional;
 
 public class SAMRecordUnitTest extends HtsjdkTest {
 
@@ -568,6 +571,70 @@ public class SAMRecordUnitTest extends HtsjdkTest {
         Assert.assertTrue(validationErrors != null && validationErrors.size() == 1);
     }
 
+    @DataProvider
+    public Object [][] binFieldValidationData() {
+        return new Object[][]{
+                {1519, 4681, 51, 16571, false},
+                {1519, 4685, 51, 16571, true},
+                {16500, 4681, 51, 16571, true},
+                {100000, 4687, 1000, 500_000_000, false},
+                {300000000, 44, 1000000, 500_000_000, false},
+                {300000000, 100000, 1000000, 500_000_000, true},
+
+                {100000, 4681, 1000, 1000_000_000, false},
+                {100000, 4681, 10000, 2000_000_000, false},
+        };
+    }
+
+    @Test(dataProvider = "binFieldValidationData")
+    public void testBinFieldValidation(final int alignmentStart,
+                                       final int bin,
+                                       final int readLength,
+                                       final int referenceLength,
+                                       final boolean isErrorExpected) {
+        final SAMRecord sam = createSamRecordWithHeaderAndBin(alignmentStart, bin, readLength, referenceLength);
+
+        final List<SAMValidationError> errorList = sam.isValid(false);
+
+        final boolean hasError = Optional.ofNullable(errorList)
+                .map(Collection::stream)
+                .map(stream -> stream.anyMatch(error -> error.getType() == SAMValidationError.Type.INVALID_INDEXING_BIN))
+                .orElse(false);
+        Assert.assertEquals(hasError, isErrorExpected);
+    }
+
+    private SAMRecord createSamRecordWithHeaderAndBin(final int alignmentStart,
+                                                      final int bin,
+                                                      final int readLength,
+                                                      final int referenceLength) {
+        final SAMRecord rec = createSamRecord(alignmentStart, readLength);
+        rec.setIndexingBin(bin);
+
+        final String referenceName = "Sheila";
+        rec.setReferenceName(referenceName);
+
+        final SAMFileHeader header = createHeaderWithOneReference(referenceName, referenceLength);
+        rec.setHeader(header);
+
+        return rec;
+    }
+
+    private SAMRecord createSamRecord(final int alignmentStart, final int readLength) {
+        final SAMRecordSetBuilder recordsBuilder = new SAMRecordSetBuilder();
+        recordsBuilder.setReadLength(readLength);
+        return recordsBuilder.addFrag("test", 0, alignmentStart, false, false, readLength + "M", null, 2);
+    }
+
+    private SAMFileHeader createHeaderWithOneReference(final String referenceName, final int referenceLength) {
+        final SAMSequenceRecord sequenceRecord = new SAMSequenceRecord(referenceName, referenceLength);
+        final List<SAMSequenceRecord> records = Collections.singletonList(sequenceRecord);
+        final SAMSequenceDictionary dict = new SAMSequenceDictionary(records);
+        final SAMFileHeader header = new SAMFileHeader(dict);
+        final SAMReadGroupRecord groupRecord = new SAMReadGroupRecord("1");
+        header.setReadGroups(Collections.singletonList(groupRecord));
+        return header;
+    }
+
     // ----------------- NULL header tests ---------------------
 
     @Test
